@@ -7,11 +7,10 @@
   FROM {{ dst_schema }}{{ table }} AS l
 {%- if type == 'not_null' %}
  WHERE l.{{ name }} IS NULL
-{%- elif type == 'values' %}
- WHERE l.{{ name }} NOT IN ( {{ values }} )
+{%- elif type == 'allowed_values' %}
+ WHERE l.{{ name }} NOT IN ( {{ allowed_values }} )
 {%- endif %}
  GROUP BY l.{{ name }}
-HAVING COUNT(*) > {%- if type == 'unique' %} 1 {%- else %} 0 {%- endif %}
-LIMIT 5)
+HAVING COUNT(*) > {%- if type == 'unique' %} 1 {%- else %} 0 {%- endif %})
 
 UNION ALL
